# PDSim
A python/cython-based air simulation code for positive-displacement compressors and expanders

This version uses CoolProp v6.x

The documention is available on ReadTheDocs: [![Documentation Status](https://readthedocs.org/projects/pdsim/badge/?version=latest)](http://pdsim.readthedocs.io/en/latest/?badge=latest)
